@@ -148,9 +148,9 @@ clearlooks_gummy_draw_top_left_highlight (cairo_t *cr, const CairoColor *color,
 {
 	CairoColor hilight;
 
-	double light_top = params->ythickness-1,
+	double light_top = params->ythickness - 1,
 	       light_bottom = height - params->ythickness - 1,
-	       light_left = params->xthickness-1,
+	       light_left = params->xthickness - 1,
 	       light_right = width - params->xthickness - 1;
 
 	ge_shade_color (color, TOPLEFT_HIGHLIGHT_SHADE, &hilight);
@@ -181,14 +181,10 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
 
-	/* Shadows and Glow */
-	if (params->xthickness == 3 || params->ythickness == 3)
-	{
-		if (params->xthickness == 3)
-			xoffset = 1;
-		if (params->ythickness == 3)
-			yoffset = 1;
-	}
+	if (params->xthickness == 3)
+		xoffset = 1;
+	if (params->ythickness == 3)
+		yoffset = 1;
 
 	radius = MIN (params->radius, MIN ((width - 2.0 - 2*xoffset) / 2.0, (height - 2.0 - 2*yoffset) / 2.0));
 
@@ -317,7 +313,7 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	if (params->focus)
 	{
 		/* ge_cairo_rounded_rectangle (cr, 2, 2, width-5, height-5, RADIUS-1, params->corners); */
-		ge_cairo_set_color (cr, &colors->spot[0]);
+		clearlooks_set_mixed_color (cr, base, &colors->spot[1], 0.5);
 		ge_cairo_stroke_rectangle (cr, 2, 2, width-5, height-5);
 	}
 	else
@@ -407,11 +403,11 @@ clearlooks_gummy_draw_progressbar_fill (cairo_t                     *cr,
                                         const ProgressBarParameters *progressbar,
                                         int x, int y, int width, int height, gint offset)
 {
-	boolean      is_horizontal = progressbar->orientation < 2;
-	double       tile_pos = 0;
-	double       stroke_width;
-	double       radius;
-	int          x_step;
+	boolean is_horizontal = progressbar->orientation < 2;
+	double  tile_pos = 0;
+	double  stroke_width;
+	double  radius;
+	int     x_step;
 
 	cairo_pattern_t *pattern;
 	CairoColor       shade1, shade2, shade3;
@@ -592,8 +588,8 @@ clearlooks_gummy_draw_scale_trough (cairo_t                *cr,
                                     const SliderParameters *slider,
                                     int x, int y, int width, int height)
 {
-	int     trough_width, trough_height;
-	double  translate_x, translate_y;
+	int    trough_width, trough_height;
+	double translate_x, translate_y;
 
 	if (slider->horizontal)
 	{
@@ -656,24 +652,20 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
                            int x, int y, int width, int height)
 {
 
-	const CairoColor    *border        = &colors->shade[5];
-	const CairoColor    *stripe_fill   = &colors->spot[1];
-	const CairoColor    *stripe_border = &colors->spot[2];
-	const CairoColor    *fill;
+	const CairoColor *border        = &colors->shade[5];
+	const CairoColor *stripe_fill   = &colors->spot[1];
+	const CairoColor *stripe_border = &colors->spot[2];
+	const CairoColor *fill;
 
-	cairo_pattern_t     *pattern = NULL;
+	cairo_pattern_t  *pattern = NULL;
 
-	double               radius;
-	
-	double               stripe_size = 2.0;
-	double               stripe_fill_size;
-	double               stripe_border_pos;
+	double            radius;
+	double            stripe_size = 2.0;
+	double            stripe_fill_size;
+	double            stripe_border_pos;
 
 	gboolean horizontal = FALSE;
 
-	if (params->ythickness == 3)
-		stripe_size = 3.0;
-
 	radius = MIN (params->radius, MIN ((width - 2.0) / 2.0, (height - 2.0) / 2.0));
 
 	/* Set clip */
@@ -689,6 +681,9 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	/* And calculate the strip size too, while you're at it */
 	if (tab->gap_side == CL_GAP_TOP || tab->gap_side == CL_GAP_BOTTOM)
 	{
+		if (params->ythickness == 3)
+			stripe_size = 3.0;
+		
 		height += 3.0;
 		stripe_fill_size = (tab->gap_side == CL_GAP_TOP ? stripe_size/height : stripe_size/(height-2));
 		stripe_border_pos = (tab->gap_side == CL_GAP_TOP ? (stripe_size+1.0)/height : (stripe_size+1.0)/(height-2));
@@ -700,6 +695,9 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	}
 	else
 	{
+		if (params->xthickness == 3)
+			stripe_size = 3.0;
+		
 		width += 3.0;
 		stripe_fill_size = (tab->gap_side == CL_GAP_LEFT ? stripe_size/width : stripe_size/(width-2));
 		stripe_border_pos = (tab->gap_side == CL_GAP_LEFT ? (stripe_size+1.0)/width : (stripe_size+1.0)/(width-2));
@@ -857,33 +855,33 @@ clearlooks_gummy_draw_separator (cairo_t                   *cr,
 
 	if (separator->horizontal)
 	{
-		cairo_set_line_width  (cr, 1.0);
-		cairo_translate       (cr, x, y+0.5);
+		cairo_set_line_width (cr, 1.0);
+		cairo_translate      (cr, x, y+0.5);
 
-		cairo_move_to         (cr, 0.0,   0.0);
-		cairo_line_to         (cr, width, 0.0);
-		ge_cairo_set_color    (cr, &color);
-		cairo_stroke          (cr);
+		cairo_move_to        (cr, 0.0,   0.0);
+		cairo_line_to        (cr, width, 0.0);
+		ge_cairo_set_color   (cr, &color);
+		cairo_stroke         (cr);
 
-		cairo_move_to         (cr, 0.0,   1.0);
-		cairo_line_to         (cr, width, 1.0);
-		ge_cairo_set_color    (cr, &hilight);
-		cairo_stroke          (cr);
+		cairo_move_to        (cr, 0.0,   1.0);
+		cairo_line_to        (cr, width, 1.0);
+		ge_cairo_set_color   (cr, &hilight);
+		cairo_stroke         (cr);
 	}
 	else
 	{
-		cairo_set_line_width  (cr, 1.0);
-		cairo_translate       (cr, x+0.5, y);
+		cairo_set_line_width (cr, 1.0);
+		cairo_translate      (cr, x+0.5, y);
 
-		cairo_move_to         (cr, 0.0, 0.0);
-		cairo_line_to         (cr, 0.0, height);
-		ge_cairo_set_color    (cr, &color);
-		cairo_stroke          (cr);
+		cairo_move_to        (cr, 0.0, 0.0);
+		cairo_line_to        (cr, 0.0, height);
+		ge_cairo_set_color   (cr, &color);
+		cairo_stroke         (cr);
 
-		cairo_move_to         (cr, 1.0, 0.0);
-		cairo_line_to         (cr, 1.0, height);
-		ge_cairo_set_color    (cr, &hilight);
-		cairo_stroke          (cr);
+		cairo_move_to        (cr, 1.0, 0.0);
+		cairo_line_to        (cr, 1.0, height);
+		ge_cairo_set_color   (cr, &hilight);
+		cairo_stroke         (cr);
 	}
 
 	cairo_restore (cr);
@@ -896,8 +894,8 @@ clearlooks_gummy_draw_slider (cairo_t                *cr,
                               int x, int y, int width, int height)
 {
 	const CairoColor *border = &colors->shade[7];
-	CairoColor  fill;
-	CairoColor  shade1, shade2, shade3;
+	CairoColor fill;
+	CairoColor shade1, shade2, shade3;
 	cairo_pattern_t *pattern;
 	int bar_x, i;
 	int shift_x;
@@ -916,10 +914,10 @@ clearlooks_gummy_draw_slider (cairo_t                *cr,
 	ge_shade_color (&fill, SHADE_BOTTOM, &shade3);
 
 	pattern = cairo_pattern_create_linear (1, 1, 1, height-2);
-	cairo_pattern_add_color_stop_rgb(pattern, 0,   shade1.r, shade1.g, shade1.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 0.5, shade2.r, shade2.g, shade2.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 0.5, fill.r, fill.g, fill.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 1.0, shade3.r, shade3.g, shade3.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 0,   shade1.r, shade1.g, shade1.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 0.5, shade2.r, shade2.g, shade2.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 0.5, fill.r, fill.g, fill.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 1.0, shade3.r, shade3.g, shade3.b);
 	cairo_rectangle (cr, 1, 1, width-2, height-2);
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
@@ -1009,14 +1007,14 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 		pattern = cairo_pattern_create_linear (0, 0, width, 0);
 
 	fill = colors->bg[widget->state_type];
-	ge_shade_color(&fill, SHADE_TOP, &shade1);
-	ge_shade_color(&fill, SHADE_CENTER_TOP, &shade2);
-	ge_shade_color(&fill, SHADE_BOTTOM, &shade3);
+	ge_shade_color (&fill, SHADE_TOP, &shade1);
+	ge_shade_color (&fill, SHADE_CENTER_TOP, &shade2);
+	ge_shade_color (&fill, SHADE_BOTTOM, &shade3);
 
-	cairo_pattern_add_color_stop_rgb(pattern, 0,   shade1.r, shade1.g, shade1.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 0.5, shade2.r, shade2.g, shade2.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 0.5, fill.r, fill.g, fill.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 1.0, shade3.r, shade3.g, shade3.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 0,   shade1.r, shade1.g, shade1.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 0.5, shade2.r, shade2.g, shade2.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 0.5, fill.r, fill.g, fill.b);
+	cairo_pattern_add_color_stop_rgb (pattern, 1.0, shade3.r, shade3.g, shade3.b);
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
@@ -1125,7 +1123,7 @@ clearlooks_gummy_draw_scrollbar_slider (cairo_t                   *cr,
 		cairo_line_to (cr, 1.5, 1.5);
 		cairo_line_to (cr, width-1.5, 1.5);
 		cairo_set_source_rgba (cr, hilight.r, hilight.g, hilight.b, TOPLEFT_HIGHLIGHT_ALPHA);
-		cairo_stroke(cr);
+		cairo_stroke (cr);
 	}
 
 	ge_cairo_set_color (cr, &border);
@@ -1298,7 +1296,7 @@ clearlooks_gummy_draw_menuitem (cairo_t                *cr,
 	cairo_pattern_add_color_stop_rgb (pattern, 1,	shade3.r, shade3.g, shade3.b);
 
 	cairo_set_source (cr, pattern);
-	cairo_fill_preserve  (cr);
+	cairo_fill_preserve (cr);
 	cairo_pattern_destroy (pattern);
 
 	ge_cairo_set_color (cr, border);
@@ -1330,7 +1328,7 @@ clearlooks_gummy_draw_menubaritem (cairo_t                *cr,
 	cairo_pattern_add_color_stop_rgb (pattern, 1,	shade3.r, shade3.g, shade3.b);
 
 	cairo_set_source (cr, pattern);
-	cairo_fill_preserve  (cr);
+	cairo_fill_preserve (cr);
 	cairo_pattern_destroy (pattern);
 
 	ge_cairo_set_color (cr, border);
@@ -1450,8 +1448,8 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 			cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
 			cairo_set_line_width (cr, 4);
 
-			cairo_move_to(cr, 5, 7);
-			cairo_line_to(cr, 9, 7);
+			cairo_move_to (cr, 5, 7);
+			cairo_line_to (cr, 9, 7);
 
 			ge_cairo_set_color (cr, dot);
 			cairo_stroke (cr);
@@ -1504,7 +1502,7 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 	if (widget->xthickness > 2 && widget->ythickness > 2)
 	{
 		widget->style_functions->draw_inset (cr, &widget->parentbg, 0.5, 0.5,
-		                         width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
+		                                     width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
 
 		/* Draw the rectangle for the checkbox itself */
 		ge_cairo_rounded_rectangle (cr, 1.5, 1.5,
@@ -1555,88 +1553,121 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 
 static void
 clearlooks_gummy_draw_focus (cairo_t *cr,
-                             const ClearlooksColors          *colors,
-                             const WidgetParameters          *widget,
-                             const FocusParameters           *focus,
+                             const ClearlooksColors *colors,
+                             const WidgetParameters *widget,
+                             const FocusParameters  *focus,
                              int x, int y, int width, int height)
 {
-	double xoffset, yoffset;
-	const CairoColor *fill = &focus->color;
-	CairoColor shade1, shade2, shade3;
+	CairoColor fill = focus->color;
+	CairoColor fill_shade1, fill_shade2, fill_shade3;
 	CairoColor border;
-	boolean fill_focus = TRUE; /* Useful in the future for selected cells */
-	boolean stroke_focus = TRUE; /* Useful? */
-	double radius = widget->radius - 1.0;
 	
-	ge_shade_color (fill, 0.65, &border);
-	ge_shade_color (fill, SHADE_TOP, &shade1);
-	ge_shade_color (fill, SHADE_CENTER_TOP, &shade2);
-	ge_shade_color (fill, SHADE_BOTTOM, &shade3);
+	/* Default values */
+	double xoffset = 1.5;
+	double yoffset = 1.5;
+	double radius = widget->radius-1.0;
+	double border_alpha = 0.7;
+	double fill_alpha = 0.2;
+	double shadow_alpha = 0.5;
+	boolean focus_fill = TRUE;
+	boolean focus_border = TRUE;
+	boolean focus_shadow = FALSE;
+	
+	ge_shade_color (&fill, 0.65, &border);
+	ge_shade_color (&fill, 1.18, &fill_shade1);
+	ge_shade_color (&fill, 1.02, &fill_shade2);
+	ge_shade_color (&fill, 0.84, &fill_shade3);
 	
 	/* Do some useful things to adjust focus */
 	switch (focus->type)
 	{
 		case CL_FOCUS_BUTTON:
-			xoffset = -0.5;
-			yoffset = -0.5;
+			xoffset = -1.5-(focus->padding);
+			yoffset = -1.5-(focus->padding);
+			radius++;
+			border_alpha = 0.9;
+			fill_alpha = 0.14;
+			if (!widget->active)
+				focus_shadow = TRUE;
+			break;
+		case CL_FOCUS_BUTTON_FLAT:
+			xoffset = -1.5-(focus->padding);
+			yoffset = -1.5-(focus->padding);
+			radius++;
+			if (widget->active || widget->prelight)
+			{
+				border_alpha = 0.9;
+				fill_alpha = 0.14;
+				if (!widget->active)
+					focus_shadow = TRUE;
+			}
 			break;
 		case CL_FOCUS_LABEL:
-			xoffset = 0.5;
-			yoffset = 0.5;
-			break;
-		case CL_FOCUS_TREEVIEW_DND:
 			xoffset = 1.5;
 			yoffset = 1.5;
 			break;
+		case CL_FOCUS_TREEVIEW:
+			border_alpha = 0.5;
+			fill_alpha = 0.14;
+			break;
+		case CL_FOCUS_TREEVIEW_DND:
+			break;
 		case CL_FOCUS_TREEVIEW_HEADER:
 			cairo_translate (cr, -1, 0);
-			xoffset = 1.5;
-			yoffset = 1.5;
 			break;
 		case CL_FOCUS_TREEVIEW_ROW:
-			fill_focus = FALSE;
-			xoffset = 1.5;
-			yoffset = 1.5;
+			xoffset = -0.5; /* hack to hide vertical lines */
+			yoffset = 0.5;
+			radius = 0;
+			ge_shade_color (&colors->base[widget->state_type], 0.75, &border);
+			border_alpha = 1.0;
+			focus_fill = FALSE;
 			break;
 		case CL_FOCUS_TAB:
-			xoffset = 1.5;
-			yoffset = 1.5;
+			radius--;
 			break;
 		case CL_FOCUS_SCALE:
-			xoffset = 1.5;
-			yoffset = 1.5;
+			break;
+		case CL_FOCUS_UNKNOWN:
+			return;
 			break;
 		default:
-			xoffset = 1.5;
-			yoffset = 1.5;
 			break;
 	};
 	
-	cairo_set_line_width (cr, 1.0);
+	cairo_translate (cr, x, y);
+	cairo_set_line_width (cr, focus->line_width);
 	
-	ge_cairo_rounded_rectangle (cr, x+xoffset, y+yoffset, width - xoffset*2, height - yoffset*2, radius, widget->corners);
+	ge_cairo_rounded_rectangle (cr, xoffset, yoffset, width-(xoffset*2), height-(yoffset*2), radius, widget->corners);
 	
-	if (fill_focus)
+	if (focus_fill)
 	{
 		cairo_pattern_t *pattern;
 		
-		cairo_translate (cr, x, y);
-		
 		pattern = cairo_pattern_create_linear (0, 0, 0, height);
-		cairo_pattern_add_color_stop_rgba (pattern, 0.0, shade1.r, shade1.g, shade1.b, 0.2);
-		cairo_pattern_add_color_stop_rgba (pattern, 0.5, shade2.r, shade2.g, shade2.b, 0.2);
-		cairo_pattern_add_color_stop_rgba (pattern, 0.5, fill->r,  fill->g,  fill->b,  0.2);
-		cairo_pattern_add_color_stop_rgba (pattern, 1.0, shade3.r, shade3.g, shade3.b, 0.2);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.0, fill_shade1.r, fill_shade1.g, fill_shade1.b, fill_alpha);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.5, fill_shade2.r, fill_shade2.g, fill_shade2.b, fill_alpha);
+		cairo_pattern_add_color_stop_rgba (pattern, 0.5, fill.r,        fill.g,        fill.b,        fill_alpha);
+		cairo_pattern_add_color_stop_rgba (pattern, 1.0, fill_shade3.r, fill_shade3.g, fill_shade3.b, fill_alpha);
 		cairo_set_source (cr, pattern);
 		cairo_fill_preserve (cr);
+		
 		cairo_pattern_destroy (pattern);
 	}
 	
-	if (stroke_focus)
+	if (focus_border)
 	{
-		border.a = 0.6;
-		ge_cairo_set_color (cr, &border);
-		cairo_stroke(cr);
+		clearlooks_set_mixed_color (cr, &widget->parentbg, &border, border_alpha);
+		cairo_stroke (cr);
+	}
+	
+	if (focus_shadow)
+	{
+		if (radius > 0)
+			radius++;
+		ge_cairo_rounded_rectangle (cr, xoffset-1, yoffset-1, width-(xoffset*2)+2, height-(yoffset*2)+2, radius, widget->corners);
+		clearlooks_set_mixed_color (cr, &widget->parentbg, &fill, shadow_alpha);
+		cairo_stroke (cr);
 	}
 }
 
