@@ -1,5 +1,7 @@
-/* Clearlooks Engine
+/* Clearlooks theme engine
  * Copyright (C) 2005 Richard Stellingwerff.
+ * Copyright (C) 2007 Benjamin Berg
+ * Copyright (C) 2007 Andrea Cimitan
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,15 +22,19 @@
  * and by Alexander Larsson <alexl@redhat.com>
  * Modified by Richard Stellingwerff <remenic@gmail.com>
  */
+ 
 #include <gtk/gtkstyle.h>
 
+#ifndef CLEARLOOKS_STYLE_H
+#define CLEARLOOKS_STYLE_H
+
 #include "animation.h"
 #include "clearlooks_types.h"
 
 typedef struct _ClearlooksStyle ClearlooksStyle;
 typedef struct _ClearlooksStyleClass ClearlooksStyleClass;
 
-extern GType clearlooks_type_style;
+GE_INTERNAL extern GType clearlooks_type_style;
 
 #define CLEARLOOKS_TYPE_STYLE              clearlooks_type_style
 #define CLEARLOOKS_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), CLEARLOOKS_TYPE_STYLE, ClearlooksStyle))
@@ -42,20 +48,27 @@ struct _ClearlooksStyle
 	GtkStyle parent_instance;
 
 	ClearlooksColors colors;
-	
-	guint8   progressbarstyle;
+
+	ClearlooksStyles style;
+
 	guint8   menubarstyle;
-	guint8   menuitemstyle;
-	guint8   listviewitemstyle;
+	guint8   toolbarstyle;
+	GdkColor focus_color;
+	gboolean has_focus_color;
 	GdkColor scrollbar_color;
+	gboolean colorize_scrollbar;
 	gboolean has_scrollbar_color;
 	gboolean animation;
+	gfloat   radius;
 };
 
 struct _ClearlooksStyleClass
 {
-  GtkStyleClass parent_class;
+	GtkStyleClass parent_class;
+
+	ClearlooksStyleFunctions style_functions[CL_NUM_STYLES];
 };
 
+GE_INTERNAL void clearlooks_style_register_type (GTypeModule *module);
 
-void clearlooks_style_register_type (GTypeModule *module);
+#endif /* CLEARLOOKS_STYLE_H */
